@@ -22,8 +22,9 @@
                         if (isset($_POST['EMAIL'])) {
                             $email['FROMMAIL'] = "yourname@yourdomain.com";
                             $email['SUBJECT'] = "Test Emailversand von OPList";
-                            $email['MSG'] = "Wenn Sie diese Nachricht erhalten haben,\ndann ist Email auf Ihrem Server richtig konfiguriert.";
-                            $email['HEADERS'] = "Return-path: ".$_POST['ABSENDER']."\n";
+                            $email['MSG'] = "<html><body><div style='font-size: 14pt;'>Wenn Sie diese Nachricht erhalten haben,</div><div style='font-size: 14pt;'>dann ist Email auf Ihrem Server richtig konfiguriert.</div><div style='font-size: 14pt;'>&nbsp;</div><div style='font-size: 14pt;'><a href=http://www.orf.at/ target=_blank>Testlink</a></div></body></html>";
+                            $email['HEADERS'] = "Content-type: text/html; charset=utf-8\n";
+                            $email['HEADERS'] .= "Return-path: ".$_POST['ABSENDER']."\n";
                             $email['HEADERS'] .= "From: <".$_POST['ABSENDER'].">\n";
                             $email['HEADERS'] .= "Reply-To: <".$_POST['ABSENDER'].">\n";
                             $email['TOMAIL'] = $_POST['EMAIL'];
