@@ -41,6 +41,8 @@
 #                  werden kann, ob ein IBN auch OP-Punkte anlegen darf
 #                  oder nicht
 # v2014-11-19 Paco Fehler bei Passwortaenderung behoben
+# v2014-11-24 Paco Sonderzeichen bei Emails behoben; Emailversand jetzt
+#                  in HTML-Format mit integriertem Link
 ######################################################################
 ####  Variables that should be adapted if necessary
 ####------------------------------------------------------------------
@@ -70,6 +72,7 @@ $mailModus = $iniParams["mailModus"];
 $mailGroup = $iniParams["mailGroup"];
 $debugMail = $iniParams["debugMail"];
 $debugSQL = $iniParams["debugSQL"];
+$EmailFontSize = $iniParams["EmailFontSize"];
 # global connection
 $connection = null;
 # overall action switch
@@ -98,7 +101,7 @@ $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <body link="#0000FF" vlink="#0000FF">
     <div class="header"><img src="img/logo.jpg" width=114 height=48 border=0 alt="OPList">';
 
-$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v2.0.579 (2014-11-21)</small></div></body></html>';
+$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v2.1.583 (2014-11-24)</small></div></body></html>';
 
 
 session_start();
@@ -178,6 +181,16 @@ if (!isset($IBNcanAddOPEntries)) {
     logIntoFile("IBNcanAddOPEntries hat einen Wert - naemlich <".$IBNcanAddOPEntries.">");
 }
 
+if (!isset($EmailFontSize)) {
+    logIntoFile("Wir setzen EmailFontSize");
+    $EmailFontSize = 14;
+    file_put_contents($configFile, "; ####------------------------------------------------------------------\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "; # Schriftgroesse fuer emails\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "EmailFontSize = 14;\n", FILE_APPEND | LOCK_EX);
+} else {
+    logIntoFile("EmailFontSize hat einen Wert - naemlich <".$EmailFontSize.">");
+}
+
 
 #---------------------------------------------------------------------
 # (c) www.glawar.at: liefert in Abhaengigkeit der obigen Parameter in
@@ -774,26 +787,26 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
-		
-		# determine the id of the op entry
-		$sQuery = "SELECT OPID FROM OPLIST WHERE OPENTRY = '" . str_replace("'","''",$_POST['OPENTRY']) . "' ORDER BY OPDATECREATED DESC";
-		debugIntoFile("Get-ID of actual OP-Query: <".$sQuery.">");
+
+        # determine the id of the op entry
+        $sQuery = "SELECT OPID FROM OPLIST WHERE OPENTRY = '" . str_replace("'","''",$_POST['OPENTRY']) . "' ORDER BY OPDATECREATED DESC";
+        debugIntoFile("Get-ID of actual OP-Query: <".$sQuery.">");
         $result = getRessource($sQuery);
         echo getError();
-        
+
         $foundOPID = 0;
         while ($val = getRow($result)) {
-			if ($foundOPID == 0) {
-				$foundOPID = $val['OPID'];
-				logIntoFile("ID of last inserted OPEntry <".$val['OPID'].">");
+            if ($foundOPID == 0) {
+                $foundOPID = $val['OPID'];
+                logIntoFile("ID of last inserted OPEntry <".$val['OPID'].">");
             }
         }
         freeRessource($result);
-		
-		# add file if some added
-		if (!empty($_FILES['datei']['name'])) {
+
+        # add file if some added
+        if (!empty($_FILES['datei']['name'])) {
             if ($usedb == "mysql") {
-				$nextId = "null";
+                $nextId = "null";
                 $sQuery = "INSERT INTO OPLIST_FILE (OPLFT) VALUES (1)";
                 debugIntoFile("Naechste-File-Id-ermitteln-Select: <".$sQuery.">");
                 #if ($debugSQL == 1) {
@@ -804,7 +817,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
                 $newFileName = mysql_insert_id();
             } else if ($usedb == "oracle") {
-				$nextId="OPLISTCOMMENT_SEQ.nextval";
+                $nextId="OPLISTCOMMENT_SEQ.nextval";
                 $sQuery = "SELECT OPLISTFILENAME_SEQ.NEXTVAL FROM DUAL";
                 debugIntoFile("Naechstes-Attachment-Select: <".$sQuery.">");
                 #if ($debugSQL == 1) {
@@ -829,14 +842,14 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 echo "Die Datei ".$_FILES['datei']['name']." konnte nicht gespeichert werden.";
             }
             $newFileName = "'".$newFileName."'";
-			$sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", 'Dateianhang zur OP-Beschreibung oben', ".$foundOPID.", 0, ".$newFileName.")";
-			debugIntoFile("Insert-Attachment-Select: <".$sQuery.">");
-			$result = getRessource($sQuery);
-			echo getError();
-			freeRessource($result);
+            $sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", 'Dateianhang zur OP-Beschreibung oben', ".$foundOPID.", 0, ".$newFileName.")";
+            debugIntoFile("Insert-Attachment-Select: <".$sQuery.">");
+            $result = getRessource($sQuery);
+            echo getError();
+            freeRessource($result);
         }
-		
-		
+
+
         #logIntoFile("I am the debug Tester");
         logIntoFile("mailModus <".$mailModus.">");
         logIntoFile("debugMail <".$debugMail.">");
@@ -845,8 +858,20 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             # wir schicken den Betroffenen eine Email
             $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
             $email['SUBJECT'] = $projectName." - Neuer OP-Punkt: ".$_POST['OPENTRY'];
-            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\nwurde hinzugefügt.";
+
+            $email['MSG'] = "<html><body>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>Der OP-Punkt</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>".$_POST['OPENTRY']."</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>wurde hinzugefügt.</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'><a href=".$appUrl."/index.php?mode=comment&OPID=".$foundOPID." target=_blank>".$appUrl."/index.php?mode=comment&OPID=".$foundOPID."</a></div>";
+            $email['MSG'] .= "</body></html>";
+
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
+            $email['HEADERS'] .= "Content-type: text/html; charset=utf-8\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
             $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$OPUID_ASSIGNED.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
@@ -868,8 +893,8 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         }
     } else if (isset($_POST['addcomment'])) {
         $OPCPRIVATE = "0";
-		
-		
+
+
 
         if (isset ($_POST["OPCHANGESTATUS"]) && $_POST["OPCHANGESTATUS"] == "on") {
             // we will change the status directly
@@ -894,14 +919,14 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 freeRessource($result);
             }
         }
-		
-		if (isset ($_POST["OPSIDNEW"])) {
-			$sQuery = "UPDATE OPLIST set OPSID = ".$_POST["OPSIDNEW"]." WHERE OPID = ".$_POST["OPID"];
-			debugIntoFile("update status of op entry: <".$sQuery.">");
-			$result = getRessource($sQuery);
-			echo getError();
-			freeRessource($result);
-		}
+
+        if (isset ($_POST["OPSIDNEW"])) {
+            $sQuery = "UPDATE OPLIST set OPSID = ".$_POST["OPSIDNEW"]." WHERE OPID = ".$_POST["OPID"];
+            debugIntoFile("update status of op entry: <".$sQuery.">");
+            $result = getRessource($sQuery);
+            echo getError();
+            freeRessource($result);
+        }
 
 
         if (isset ($_POST["OPCPRIVATE"]) && $_POST["OPCPRIVATE"] == "on") {
@@ -1005,8 +1030,20 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             }
             if ($sendMail == 1) {
                 $email['SUBJECT'] = $projectName." - Neuer Kommentar zu OP-Punk: ".$_POST['OPID']."-".$opEntry;
-                $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPID']."-".$opEntry."\n\nerhielt einen neuen Kommentar.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]."\n\n\n\n".$_POST["OPCTEXT"];
+
+                $email['MSG'] = "<html><body>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>Der OP-Punkt</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>".$_POST['OPID']."-".$opEntry."</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>erhielt einen neuen Kommentar.</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'><a href=".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]." target=_blank>".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]."</a></div>";
+                $email['MSG'] .= "</body></html>";
+
                 $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
+                $email['HEADERS'] .= "Content-type: text/html; charset=utf-8\n";
                 $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
                 $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
                 $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$tempToMail.",".$assigned.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
@@ -1049,8 +1086,20 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
             $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
             $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$OPName;
-            $email['MSG'] = "Der OP-Punkt\n\n".$OPName."\n\nwurde aktualisiert.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
+
+            $email['MSG'] = "<html><body>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>Der OP-Punkt</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>".$OPName."</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>wurde aktualisiert.</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'><a href=".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]." target=_blank>".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]."</a></div>";
+            $email['MSG'] .= "</body></html>";
+
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
+            $email['HEADERS'] .= "Content-type: text/html; charset=utf-8\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
 
@@ -1170,8 +1219,20 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             }
             if ($sendMail == 1) {
                 $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$_POST['OPID']."-".$_POST['OPENTRY'];
-                $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPID']."-".$_POST['OPENTRY']."\n\nwurde aktualisiert.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
+
+                $email['MSG'] = "<html><body>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>Der OP-Punkt</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>".$_POST['OPID']."-".$_POST['OPENTRY']."</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>wurde aktualisiert.</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+                $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'><a href=".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]." target=_blank>".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]."</a></div>";
+                $email['MSG'] .= "</body></html>";
+
                 $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
+                $email['HEADERS'] .= "Content-type: text/html; charset=utf-8\n";
                 $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
                 $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
                 $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$tempToMail.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
@@ -1193,8 +1254,20 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         } else if ($mailModus == 2) {
             $email['FROMMAIL'] = getEmailOfId ($oldUIdCreated);
             $email['SUBJECT'] = $projectName." - Update OP-Punk: ".$_POST['OPENTRY'];
-            $email['MSG'] = "Der OP-Punkt\n\n".$_POST['OPENTRY']."\n\nwurde aktualisiert.\n\n\n".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"];
+
+            $email['MSG'] = "<html><body>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>Der OP-Punkt</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>".$_POST['OPENTRY']."</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>wurde aktualisiert.</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'>&nbsp;</div>";
+            $email['MSG'] .= "<div style='font-size: ".$EmailFontSize ."pt;'><a href=".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]." target=_blank>".$appUrl."/index.php?mode=comment&OPID=".$_POST["OPID"]."</a></div>";
+            $email['MSG'] .= "</body></html>";
+
             $email['HEADERS'] = "Return-path: ".$email['FROMMAIL']."\n";
+            $email['HEADERS'] .= "Content-type: text/html; charset=utf-8\n";
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
             $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$_POST['OPUID_ASSIGNED'].") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
@@ -1366,7 +1439,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         }
         freeRessource ($result);
         $tmpHTML .= '
-            <form method="post" name="addcommentform" enctype="multipart/form-data">
+            <form method="post" name="addcommentform" enctype="multipart/form-data" accept-charset="UTF-8">
             <center>
             <table width=98% border="0" cellpadding=3 cellspacing=2>
             <tr bgcolor="#f0f0f0" >
@@ -1453,36 +1526,36 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
 
             </td>
             <td colspan=2 align=right valign=bottom>';
-			if ($_SESSION['OPGID'] != "2") {
-				$tmpHTML .= '
-				<b>Status</b>
-				<select name="OPSIDNEW">';
-				
-					$sQuery = "SELECT OPSID FROM OPLIST WHERE OPID = ".$_GET['OPID'];
-					debugIntoFile("get status id of op entry: <".$sQuery.">");
-					$result = getRessource($sQuery);
-					echo getError();
-					
-					$foundOPStatusID = 0;
-					while ($val = getRow($result)) {
-						$foundOPStatusID = $val['OPSID'];
-					}
-					freeRessource($result);
+            if ($_SESSION['OPGID'] != "2") {
+                $tmpHTML .= '
+                <b>Status</b>
+                <select name="OPSIDNEW">';
 
-					foreach ($statArr as $k => $v) {
-						if ($foundOPStatusID == $v['OPSID']) {
-							$tmpHTML .=  '<option selected value="'.$v['OPSID'].'">' . $v['OPSTEXT'];
-						} else {
-							$tmpHTML .=  '<option value="'.$v['OPSID'].'">' . $v['OPSTEXT'];
-						}
-					}
-				
-				
-				$tmpHTML .= '
-						</select><div>&nbsp;</div><div>&nbsp;</div>';
-			}
-			$tmpHTML .= '
-			<input type="submit" name="addcomment" style="width:180px;" value="Kommentar hinzufügen" onClick="return(checkAddComment(document.addcommentform.OPCTEXT.value));">
+                    $sQuery = "SELECT OPSID FROM OPLIST WHERE OPID = ".$_GET['OPID'];
+                    debugIntoFile("get status id of op entry: <".$sQuery.">");
+                    $result = getRessource($sQuery);
+                    echo getError();
+
+                    $foundOPStatusID = 0;
+                    while ($val = getRow($result)) {
+                        $foundOPStatusID = $val['OPSID'];
+                    }
+                    freeRessource($result);
+
+                    foreach ($statArr as $k => $v) {
+                        if ($foundOPStatusID == $v['OPSID']) {
+                            $tmpHTML .=  '<option selected value="'.$v['OPSID'].'">' . $v['OPSTEXT'];
+                        } else {
+                            $tmpHTML .=  '<option value="'.$v['OPSID'].'">' . $v['OPSTEXT'];
+                        }
+                    }
+
+
+                $tmpHTML .= '
+                        </select><div>&nbsp;</div><div>&nbsp;</div>';
+            }
+            $tmpHTML .= '
+            <input type="submit" name="addcomment" style="width:180px;" value="Kommentar hinzufügen" onClick="return(checkAddComment(document.addcommentform.OPCTEXT.value));">
             <input type="hidden" name="OPID" value="'.$_GET['OPID'].'">
             </td>
             </tr>
@@ -1492,7 +1565,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             <br><br><br>';
     } else if ($mode == "new" || $mode == "edit") {
         $tmpHTML .= '
-            <form method="post" action="'.$_SERVER['PHP_SELF'].'" name="opform" enctype="multipart/form-data">
+            <form method="post" action="'.$_SERVER['PHP_SELF'].'" name="opform" enctype="multipart/form-data" accept-charset="UTF-8">
             <table width=100% border="0" cellpadding=3 cellspacing=2>';
 
         if ($mode == "edit") {
@@ -1576,12 +1649,12 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             <td colspan=2><textarea name="OPDESC" style="width:650px;" rows=10>'.$OPDESC.'</textarea></td>
             <td bgcolor="#ffffff" ></td>
         </tr>
-		<tr bgcolor="#f0f0f0" >
-			<td valign=top>&nbsp;<b>Anhang:</b></td>
-			<td colspan=2><input type="file" name="datei"></td>
-			<td bgcolor="#ffffff" ></td>
-		</tr>
-		';
+        <tr bgcolor="#f0f0f0" >
+            <td valign=top>&nbsp;<b>Anhang:</b></td>
+            <td colspan=2><input type="file" name="datei"></td>
+            <td bgcolor="#ffffff" ></td>
+        </tr>
+        ';
         if ($_SESSION['OPGID'] == "1" || $_SESSION['OPGID'] == "4") {
             $tmpHTML .= '<tr bgcolor="#f0f0f0" >
                 <td valign=middle>&nbsp;<b>Zugewiesen an:</b></td>
